import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  scaleOrdinal,
  schemeSet2
} from 'd3';
import { colorLegend } from './colorLegend';
import { loadData } from './loadData';
import { scatterplot } from './scatterplot';




//svg initialize
const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

var artists;
var selectedArtist;
var data;
const colorScale = scaleOrdinal();
const colorValue = d => d.country;


//margins
const margin = { top: 60, right: 40, bottom: 88, left: 190 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;



const title = 'GDP Variation: USA and Germany';

const sp = svg.append('g')
  .attr('transform', `translate(${margin.left},${margin.top})`);
const cl = svg.append('g')
  .attr('transform', `translate(20, 70)`);

  svg.append('text')
    .attr('class', 'title')
    .attr('x', (width + margin.left) / 2)
    .attr('y', 45)
    .text(title);


const onClick = d => {
  selectedArtist = d;
  render();
};

//loadData().then(data => {render(data)});
//data loading concept used from Nick Lima
loadData().then(processedData => {
  data = processedData;
  artists = [...new Set(data.map(d => d.country))];
  

const render = () => {colorScale.domain(artists).range(schemeSet2); 
  
  cl.call(colorLegend, {
    colorScale,
    circleRadius: 8.6,
    spacing: 21,
    textOffset: 12,
    backgroundRectWidth: 135,
    onClick,
    selectedArtist
  });
  
  sp.call(scatterplot, {
    data,
    colorScale,
    colorValue,
    selectedArtist,
    innerWidth,
    innerHeight,
    circleRadius: 4
  });
};
 